==> react-web-foundation-0.1.7.tgz: package/es/StyleSheet/index.js <==
import * as aphrodite from "aphrodite/no-important";
import getHairlineWidth from "./getHairlineWidth";
import modality from "./modality";
import processStyles from "./processStyles";

// initialize focus-ring fix
modality();

var absoluteFillObject = {
  position: "absolute",
  left: 0,
  right: 0,
  top: 0,
  bottom: 0
};

var isObject = function isObject(value) {
  return Object.prototype.toString.call(value) === "[object Object]";
};

var process = function process(styles) {
  var processedStyles = processStyles(styles);
  Object.keys(processedStyles).forEach(function (key) {
    var value = processedStyles[key];
    if (isObject(value)) {
      processedStyles[key] = process(value);
    }
  });
  return processedStyles;
};

var create = function create(styles) {
  var processedStyles = {};
  Object.keys(styles).forEach(function (key) {
    processedStyles[key] = process(styles[key]);
  });
  return aphrodite.StyleSheet.create(processedStyles);
};

var flatten = function flatten(arr) {
  return arr.reduce(function (flat, toFlatten) {
    return flat.concat(Array.isArray(toFlatten) ? flatten(toFlatten) : toFlatten);
  }, []);
};

var extractInlineStyles = function extractInlineStyles(styleArray) {
  var styles = [];
  var inlineStyles = {};
  var flattendStyles = flatten(styleArray);
  flattendStyles.forEach(function (style) {
    if (!style) {
      return;
    } else if (style._name) {
      styles.push(style);
    } else {
      Object.assign(inlineStyles, style);
    }
  });
  return { styles: styles, inlineStyles: inlineStyles };
};

var StyleSheet = {
  absoluteFill: create(absoluteFillObject),
  absoluteFillObject: absoluteFillObject,
  compose: function compose(style1, style2) {
    if (style1 && style2) {
      return [style1, style2];
    } else {
      return style1 || style2;
    }
  },

  create: create,
  hairlineWidth: getHairlineWidth(),
  resolve: function resolve(styleArray) {
    var _extractInlineStyles = extractInlineStyles(styleArray),
        styles = _extractInlineStyles.styles,
        inlineStyles = _extractInlineStyles.inlineStyles;

    return {
      className: aphrodite.css(styles),
      style: inlineStyles
    };
  }
};

export default StyleSheet;

==> react-web-foundation-0.1.9.tgz: package/es/StyleSheet/index.js <==
import * as aphrodite from "aphrodite/no-important";
import { flushToStyleTag } from "aphrodite/lib/inject";
import getHairlineWidth from "./getHairlineWidth";
import modality from "./modality";
import processStyles from "./processStyles";

// initialize focus-ring fix
modality();

var absoluteFillObject = {
  position: "absolute",
  left: 0,
  right: 0,
  top: 0,
  bottom: 0
};

var isObject = function isObject(value) {
  return Object.prototype.toString.call(value) === "[object Object]";
};

var process = function process(styles) {
  var processedStyles = processStyles(styles);
  Object.keys(processedStyles).forEach(function (key) {
    var value = processedStyles[key];
    if (isObject(value)) {
      processedStyles[key] = process(value);
    }
  });
  return processedStyles;
};

var create = function create(styles) {
  var processedStyles = {};
  Object.keys(styles).forEach(function (key) {
    processedStyles[key] = process(styles[key]);
  });
  return aphrodite.StyleSheet.create(processedStyles);
};

var flatten = function flatten(arr) {
  return arr.reduce(function (flat, toFlatten) {
    return flat.concat(Array.isArray(toFlatten) ? flatten(toFlatten) : toFlatten);
  }, []);
};

var extractInlineStyles = function extractInlineStyles(styleArray) {
  var styles = [];
  var inlineStyles = {};
  var flattendStyles = flatten(styleArray);
  flattendStyles.forEach(function (style) {
    if (!style) {
      return;
    } else if (style._name) {
      styles.push(style);
    } else {
      Object.assign(inlineStyles, style);
    }
  });
  return { styles: styles, inlineStyles: inlineStyles };
};

var StyleSheet = {
  absoluteFill: create({ style: absoluteFillObject }).style,
  absoluteFillObject: absoluteFillObject,
  compose: function compose(style1, style2) {
    if (style1 && style2) {
      return [style1, style2];
    } else {
      return style1 || style2;
    }
  },

  create: create,
  hairlineWidth: getHairlineWidth(),
  resolve: function resolve(styleArray) {
    var _extractInlineStyles = extractInlineStyles(styleArray),
        styles = _extractInlineStyles.styles,
        inlineStyles = _extractInlineStyles.inlineStyles;

    return {
      className: aphrodite.css(styles),
      style: inlineStyles
    };
  },
  flush: function flush() {
    flushToStyleTag();
  }
};

export default StyleSheet;
